Skip to main content

toml_cfg_tool

Table of Contents

Prerequisites

Description

A tool to create toml and cfg files for use in python projects, it can also simultaneously update aspects that are common between the two files.

Features

Arguments

The tool accepts the following arguments:

  • --show: Show the current configuration. (only shows the options that can be updated)
  • --author: Update the project author.
  • --name: Update the project name.
  • --version: Update the project version.
  • --description: Update the project description.
  • --requires-python: Update the required Python version.
  • --license: Update the project license.
  • --workflow_files: Add GitHub Actions workflow files, and scripts.
  • --create-templates: Create template setup.cfg and pyproject.toml files if they do not exist.
  • --backup: Backup existing configuration files before making changes.
  • --dry-run: Show changes without writing to files.

Examples

  • Show the current configuration:
toml_cfg_tool --show
  • Create template configuration files:
toml_cfg_tool --create-templates
  • Create the workflow files:
toml_cfg_tool --workflow_files
  • Show changes without writing to files:
toml_cfg_tool --dry-run --name "New Project Name" --author "New Project Author" --version "1.0.0" --description "New Project Description" --requires-python ">=3.6" --license "MIT"
  • Update the project version:
pip install toml_cfg_tool
  • Update the project name:
toml_cfg_tool --name "New Project Name"
  • Update the project author and backup existing files:
toml_cfg_tool --author "New Project Author" --backup path/to/backups.bak
  • Create template configuration files and workflow files while updating the project name, author, and version:
toml_cfg_tool --create-templates --workflow_files --name "New Project Name" --author "New Project Author" --version "1.0.0"

Screenshots

  • Show the current configuration (only shows the options that can be updated):

  • Create template configuration files:

Create the template .toml and .cfg files

  • Create the CONTRIBUTING.md file:

CONTRIBUTING.md

  • Update all available fields:

Installation and Setup

To install the tool, run the following command:

pip install toml_cfg_tool

To check if the tool is installed, run the following command:

pip show toml_cfg_tool

or

toml_cfg_tool --help

Run the application:

Any of the arguments can be used or excluded from the command below. The tool will only update the specified fields. - Use dry-run to see changes without writing to files - Use backup to backup existing files before making changes - Use create-templates to create template configuration files - Use workflow_files to create GitHub Actions workflow files

toml_cfg_tool --name "New Project Name" --author "New Project Author" --version "1.0.0" --description "New Project Description" --requires-python ">=3.6" --license "MIT"

Contributing

Contributing

License

This project is licensed under the MIT License. You can find the full text of the license in the LICENSE file.

Metadata

Release files for toml-cfg-tool 0.0.9

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for toml-cfg-tool 0.0.9
File Size Uploaded Provenance
toml_cfg_tool-0.0.9.tar.gz 9.7 kB Without provenance Details

Built distribution (wheel)

Table of built distributions (wheels) for toml-cfg-tool 0.0.9
File Interpreter ABI Platform
toml_cfg_tool-0.0.9-py3-none-any.whl Python 3 none any Details

Total release size: 22.6 kB

Release files / toml_cfg_tool-0.0.9.tar.gz

Download URL toml_cfg_tool-0.0.9.tar.gz
Size 9.7 kB
Tags Source
SHA-256 checksum
How to use checksums
6b6ef2be90f09fb5f398207b7a8ef3c050550d39ef5c5bdc47036cd1c65db22e
BLAKE2b-256 checksum
How to use checksums
4696adc5184abfb6897836951cb4f10249b8af696c30eff4dbdec881be9cc8bb
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/5.1.1 CPython/3.9.20

Release files / toml_cfg_tool-0.0.9-py3-none-any.whl

Download URL toml_cfg_tool-0.0.9-py3-none-any.whl
Size 13.0 kB
Tags Python 3
SHA-256 checksum
How to use checksums
f17a65f46bd8d266357e6f0835ebdd3aef9062ed936ccdaf9d1f43b46f38e499
BLAKE2b-256 checksum
How to use checksums
7eb64cf31b32926a68d2aa14f93eefb36befeccd430f6aa3e8754e0b68922197
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/5.1.1 CPython/3.9.20

Security for toml-cfg-tool 0.0.9

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

No provenance found

None of the files in this release were uploaded with provenance metadata.

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page